Enum orml_currencies::module::Call [−][src]
pub enum Call<T: Config> {
transfer {
dest: <T::Lookup as StaticLookup>::Source,
currency_id: <<T as Config>::MultiCurrency as MultiCurrency<<T as Config>::AccountId>>::CurrencyId,
amount: <<T as Config>::MultiCurrency as MultiCurrency<<T as Config>::AccountId>>::Balance,
},
transfer_native_currency {
dest: <T::Lookup as StaticLookup>::Source,
amount: <<T as Config>::MultiCurrency as MultiCurrency<<T as Config>::AccountId>>::Balance,
},
update_balance {
who: <T::Lookup as StaticLookup>::Source,
currency_id: <<T as Config>::MultiCurrency as MultiCurrency<<T as Config>::AccountId>>::CurrencyId,
amount: <<T as Config>::MultiCurrency as MultiCurrencyExtended<<T as Config>::AccountId>>::Amount,
},
// some variants omitted
}Expand description
Contains one variant per dispatchable that can be called by an extrinsic.
Variants
Transfer some balance to another account under currency_id.
The dispatch origin for this call must be Signed by the
transactor.
Fields of transfer
dest: <T::Lookup as StaticLookup>::Sourcecurrency_id: <<T as Config>::MultiCurrency as MultiCurrency<<T as Config>::AccountId>>::CurrencyIdamount: <<T as Config>::MultiCurrency as MultiCurrency<<T as Config>::AccountId>>::BalanceTransfer some native currency to another account.
The dispatch origin for this call must be Signed by the
transactor.
Fields of transfer_native_currency
dest: <T::Lookup as StaticLookup>::Sourceamount: <<T as Config>::MultiCurrency as MultiCurrency<<T as Config>::AccountId>>::Balanceupdate amount of account who under currency_id.
The dispatch origin of this call must be Root.
Fields of update_balance
who: <T::Lookup as StaticLookup>::Sourcecurrency_id: <<T as Config>::MultiCurrency as MultiCurrency<<T as Config>::AccountId>>::CurrencyIdamount: <<T as Config>::MultiCurrency as MultiCurrencyExtended<<T as Config>::AccountId>>::AmountImplementations
pub fn new_call_variant_transfer(
dest: <T::Lookup as StaticLookup>::Source,
currency_id: <<T as Config>::MultiCurrency as MultiCurrency<<T as Config>::AccountId>>::CurrencyId,
amount: <<T as Config>::MultiCurrency as MultiCurrency<<T as Config>::AccountId>>::Balance
) -> Self
pub fn new_call_variant_transfer(
dest: <T::Lookup as StaticLookup>::Source,
currency_id: <<T as Config>::MultiCurrency as MultiCurrency<<T as Config>::AccountId>>::CurrencyId,
amount: <<T as Config>::MultiCurrency as MultiCurrency<<T as Config>::AccountId>>::Balance
) -> Self
Create a call with the variant transfer.
pub fn new_call_variant_transfer_native_currency(
dest: <T::Lookup as StaticLookup>::Source,
amount: <<T as Config>::MultiCurrency as MultiCurrency<<T as Config>::AccountId>>::Balance
) -> Self
pub fn new_call_variant_transfer_native_currency(
dest: <T::Lookup as StaticLookup>::Source,
amount: <<T as Config>::MultiCurrency as MultiCurrency<<T as Config>::AccountId>>::Balance
) -> Self
Create a call with the variant transfer_native_currency.
pub fn new_call_variant_update_balance(
who: <T::Lookup as StaticLookup>::Source,
currency_id: <<T as Config>::MultiCurrency as MultiCurrency<<T as Config>::AccountId>>::CurrencyId,
amount: <<T as Config>::MultiCurrency as MultiCurrencyExtended<<T as Config>::AccountId>>::Amount
) -> Self
pub fn new_call_variant_update_balance(
who: <T::Lookup as StaticLookup>::Source,
currency_id: <<T as Config>::MultiCurrency as MultiCurrency<<T as Config>::AccountId>>::CurrencyId,
amount: <<T as Config>::MultiCurrency as MultiCurrencyExtended<<T as Config>::AccountId>>::Amount
) -> Self
Create a call with the variant update_balance.