Struct orml_currencies::module::Pallet [−][src]
pub struct Pallet<T>(_);Expand description
The pallet implementing the on-chain logic.
Implementations
pub fn transfer(
origin: OriginFor<T>,
dest: <T::Lookup as StaticLookup>::Source,
currency_id: <<T as Config>::MultiCurrency as MultiCurrency<<T as Config>::AccountId>>::CurrencyId,
amount: <<T as Config>::MultiCurrency as MultiCurrency<<T as Config>::AccountId>>::Balance
) -> DispatchResult
pub fn transfer(
origin: OriginFor<T>,
dest: <T::Lookup as StaticLookup>::Source,
currency_id: <<T as Config>::MultiCurrency as MultiCurrency<<T as Config>::AccountId>>::CurrencyId,
amount: <<T as Config>::MultiCurrency as MultiCurrency<<T as Config>::AccountId>>::Balance
) -> DispatchResult
Transfer some balance to another account under currency_id.
The dispatch origin for this call must be Signed by the
transactor.
pub fn transfer_native_currency(
origin: OriginFor<T>,
dest: <T::Lookup as StaticLookup>::Source,
amount: <<T as Config>::MultiCurrency as MultiCurrency<<T as Config>::AccountId>>::Balance
) -> DispatchResult
pub fn transfer_native_currency(
origin: OriginFor<T>,
dest: <T::Lookup as StaticLookup>::Source,
amount: <<T as Config>::MultiCurrency as MultiCurrency<<T as Config>::AccountId>>::Balance
) -> DispatchResult
Transfer some native currency to another account.
The dispatch origin for this call must be Signed by the
transactor.
pub fn update_balance(
origin: OriginFor<T>,
who: <T::Lookup as StaticLookup>::Source,
currency_id: <<T as Config>::MultiCurrency as MultiCurrency<<T as Config>::AccountId>>::CurrencyId,
amount: <<T as Config>::MultiCurrency as MultiCurrencyExtended<<T as Config>::AccountId>>::Amount
) -> DispatchResult
pub fn update_balance(
origin: OriginFor<T>,
who: <T::Lookup as StaticLookup>::Source,
currency_id: <<T as Config>::MultiCurrency as MultiCurrency<<T as Config>::AccountId>>::CurrencyId,
amount: <<T as Config>::MultiCurrency as MultiCurrencyExtended<<T as Config>::AccountId>>::Amount
) -> DispatchResult
update amount of account who under currency_id.
The dispatch origin of this call must be Root.