Struct orml_currencies::Currency [−][src]
pub struct Currency<T, GetCurrencyId>(_, _);Trait Implementations
impl<T, GetCurrencyId> BasicCurrency<<T as Config>::AccountId> for Currency<T, GetCurrencyId> where
T: Config,
GetCurrencyId: Get<<<T as Config>::MultiCurrency as MultiCurrency<<T as Config>::AccountId>>::CurrencyId>,
impl<T, GetCurrencyId> BasicCurrency<<T as Config>::AccountId> for Currency<T, GetCurrencyId> where
T: Config,
GetCurrencyId: Get<<<T as Config>::MultiCurrency as MultiCurrency<<T as Config>::AccountId>>::CurrencyId>,
type Balance = <<T as Config>::MultiCurrency as MultiCurrency<<T as Config>::AccountId>>::Balance
type Balance = <<T as Config>::MultiCurrency as MultiCurrency<<T as Config>::AccountId>>::Balance
The balance of an account.
Existential deposit.
The total amount of issuance.
The combined balance of who.
The free balance of who.
A dry-run of withdraw. Returns Ok iff the account is able to make a
withdrawal of the given amount. Read more
Transfer some amount from one account to another.
Add amount to the balance of who and increase total issuance.
Remove amount from the balance of who and reduce total issuance.
Same result as slash(who, value) (but without the side-effects)
assuming there are no balance changes in the meantime and only the
reserved balance is not taken into account. Read more
impl<T, GetCurrencyId> BasicCurrencyExtended<<T as Config>::AccountId> for Currency<T, GetCurrencyId> where
T: Config,
GetCurrencyId: Get<<<T as Config>::MultiCurrency as MultiCurrency<<T as Config>::AccountId>>::CurrencyId>,
impl<T, GetCurrencyId> BasicCurrencyExtended<<T as Config>::AccountId> for Currency<T, GetCurrencyId> where
T: Config,
GetCurrencyId: Get<<<T as Config>::MultiCurrency as MultiCurrency<<T as Config>::AccountId>>::CurrencyId>,
type Amount = <<T as Config>::MultiCurrency as MultiCurrencyExtended<<T as Config>::AccountId>>::Amount
type Amount = <<T as Config>::MultiCurrency as MultiCurrencyExtended<<T as Config>::AccountId>>::Amount
The signed type for balance related operations, typically signed int.
Add or remove abs(by_amount) from the balance of who. If positive
by_amount, do add, else do remove. Read more
impl<T, GetCurrencyId> BasicLockableCurrency<<T as Config>::AccountId> for Currency<T, GetCurrencyId> where
T: Config,
GetCurrencyId: Get<<<T as Config>::MultiCurrency as MultiCurrency<<T as Config>::AccountId>>::CurrencyId>,
impl<T, GetCurrencyId> BasicLockableCurrency<<T as Config>::AccountId> for Currency<T, GetCurrencyId> where
T: Config,
GetCurrencyId: Get<<<T as Config>::MultiCurrency as MultiCurrency<<T as Config>::AccountId>>::CurrencyId>,
type Moment = T::BlockNumber
type Moment = T::BlockNumber
The quantity used to denote time; usually just a BlockNumber.
fn set_lock(
lock_id: LockIdentifier,
who: &T::AccountId,
amount: Self::Balance
) -> DispatchResult
fn set_lock(
lock_id: LockIdentifier,
who: &T::AccountId,
amount: Self::Balance
) -> DispatchResult
Create a new balance lock on account who. Read more
fn extend_lock(
lock_id: LockIdentifier,
who: &T::AccountId,
amount: Self::Balance
) -> DispatchResult
fn extend_lock(
lock_id: LockIdentifier,
who: &T::AccountId,
amount: Self::Balance
) -> DispatchResult
Changes a balance lock (selected by lock_id) so that it becomes less
liquid in all parameters or creates a new one if it does not exist. Read more
Remove an existing lock.
impl<T, GetCurrencyId> BasicReservableCurrency<<T as Config>::AccountId> for Currency<T, GetCurrencyId> where
T: Config,
GetCurrencyId: Get<<<T as Config>::MultiCurrency as MultiCurrency<<T as Config>::AccountId>>::CurrencyId>,
impl<T, GetCurrencyId> BasicReservableCurrency<<T as Config>::AccountId> for Currency<T, GetCurrencyId> where
T: Config,
GetCurrencyId: Get<<<T as Config>::MultiCurrency as MultiCurrency<<T as Config>::AccountId>>::CurrencyId>,
Same result as reserve(who, value) (but without the side-effects)
assuming there are no balance changes in the meantime. Read more
Deducts up to value from reserved balance of who. This function
cannot fail. Read more
The amount of the balance of a given account that is externally reserved; this can still get slashed, but gets slashed last of all. Read more
Moves value from balance to reserved balance. Read more
Moves up to value from reserved balance to free balance. This function
cannot fail. Read more
fn repatriate_reserved(
slashed: &T::AccountId,
beneficiary: &T::AccountId,
value: Self::Balance,
status: BalanceStatus
) -> Result<Self::Balance, DispatchError>
fn repatriate_reserved(
slashed: &T::AccountId,
beneficiary: &T::AccountId,
value: Self::Balance,
status: BalanceStatus
) -> Result<Self::Balance, DispatchError>
Moves up to value from reserved balance of account slashed to
balance of account beneficiary. beneficiary must exist for this to
succeed. If it does not, Err will be returned. Funds will be placed in
either the free balance or the reserved balance, depending on the
status. Read more